package bank.infrastructure.impl;

import java.util.LinkedList;

import org.drools.KnowledgeBase;
import org.drools.runtime.StatefulKnowledgeSession;
import org.drools.runtime.rule.FactHandle;

import bank.infrastructure.Report;
import bank.infrastructure.StatefulService;
import bank.model.Account;
import bank.model.Customer;


public class StatefulServiceImpl implements StatefulService {
	
	private KnowledgeBase knowledgeBase;
	private StatefulKnowledgeSession statefulSession;
	private Report report;

	
	public StatefulServiceImpl(KnowledgeBase knowledgeBase) {
		this.knowledgeBase = knowledgeBase;
		report = new Report();
		statefulSession = createKnowledgeSession();
	}

	private StatefulKnowledgeSession createKnowledgeSession() {
		StatefulKnowledgeSession session = knowledgeBase.newStatefulKnowledgeSession();
		session.setGlobal("report", report);
		return session;
	}

	public void insertOrUpdate(Object fact) {
		if (fact == null) {
			return;
		}

		FactHandle factHandle = statefulSession.getFactHandle(fact);

		if (factHandle == null) {
			statefulSession.insert(fact);
		} else {
			statefulSession.update(factHandle, fact);
		}
	}

	public void insertOrUpdateRecursive(Customer customer) {
		insertOrUpdate(customer); 
		insertOrUpdate(customer.getAddress());
		if (customer.getAccounts() != null) {
			for (Account account : customer.getAccounts()) {
				insertOrUpdate(account);
			}
		}
	}

	public void executeRules() {
		statefulSession.fireAllRules();
	}

	public void terminate() {
		statefulSession.dispose();
	}

	public LinkedList<String> getMessages() {
		return ((Report) statefulSession.getGlobal("report")).getMessages();
	}
	
}
